@@ -11,14 +11,14 @@ from .runner.proxy import encode_proxy_url
 import requests
 import os
 
-
+__version__ = "0.1.8"
 __location__ = os.getcwd()
-refresh = Refresh
-secret = Secret
-runner = Runner
-api = Api
-static = Static
-dependency = Dependency
+refresh = Refresh()
+secret = Secret()
+runner = Runner()
+api = Api()
+static = Static()
+dependency = Dependency()
 
 
 def manager():
@@ -27,6 +27,14 @@ def manager():
     display(HTML(f'<a href="{public_url}"">Manager</a>'))
 
 
+def clean_logs():
+    req = requests.get(url="localhost:5000/logs")
+    req.raise_for_status()
+    jsn = req.json()
+    print(jsn)
+    return jsn
+
+
 def refresh_status():
     req = requests.get(url="localhost:5000/scheduler")
     req.raise_for_status()
