@@ -17,7 +17,9 @@ class Jobs:
     __json_name = "jobs.json"
 
     def __init__(self, logger, clean=False, init_data=[]):
-        self.__path_user_files = os.environ.get("JUPYTER_SERVER_ROOT", "/home/ftp")
+        self.__path_user_files = os.environ.get(
+            "JUPYTER_SERVER_ROOT", f'/home/{os.environ.get("NB_USER", "ftp")}'
+        )
         self.__path_naas_files = os.path.join(
             self.__path_user_files, self.__naas_folder
         )
