@@ -44,7 +44,7 @@ class Notebooks:
             self.__logger.info(
                 {"id": uid, "type": t_notebook, "status": "next_url", "url": next_url}
             )
-            return redirect(next_url, code=302)
+            return redirect(next_url)
         else:
             res_data = self.__get_res(res)
             if res_data and res_data.get("type") == "application/json":
@@ -127,6 +127,7 @@ class Notebooks:
                 cwd=file_dirpath,
                 parameters=params,
                 kernel_manager_class=kern_manager,
+                nest_asyncio=True,
             )
         else:
             return pm.execute_notebook(
@@ -165,6 +166,8 @@ class Notebooks:
         try:
             res = self.__pm_exec(file_dirpath, file_filepath, file_filepath_out, params)
         except pm.PapermillExecutionError as err:
+            tb = traceback.format_exc()
+            res = {"error": err, "traceback": str(tb)}
             self.__logger.error(
                 {
                     "id": uid,
@@ -175,7 +178,6 @@ class Notebooks:
                     "error": str(err),
                 }
             )
-            res = {"error": str(err)}
         except pm.PapermillException as err:
             tb = traceback.format_exc()
             res = {"error": err, "traceback": str(tb)}
@@ -190,6 +192,20 @@ class Notebooks:
                     "traceback": str(tb),
                 }
             )
+        except:  # noqa: E722
+            tb = traceback.format_exc()
+            res = {"error": "Unknow error", "traceback": str(tb)}
+            self.__logger.error(
+                {
+                    "id": uid,
+                    "type": "Exception",
+                    "status": t_error,
+                    "filepath": file_filepath,
+                    "output_filepath": file_filepath_out,
+                    "error": res.get("error"),
+                    "traceback": str(tb),
+                }
+            )
         if not res:
             res = {"error": "Unknow error"}
             self.__logger.error(
@@ -203,10 +219,10 @@ class Notebooks:
                 }
             )
         else:
-            self.__logger.error(
+            self.__logger.info(
                 {
                     "id": uid,
-                    "type": "Exception",
+                    "type": "Done",
                     "status": t_health,
                     "filepath": file_filepath,
                     "output_filepath": file_filepath_out,
